aboutsummaryrefslogtreecommitdiffstats
path: root/modules/desktop/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'modules/desktop/default.nix')
-rw-r--r--modules/desktop/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/desktop/default.nix b/modules/desktop/default.nix
index a2fdfc8..759b979 100644
--- a/modules/desktop/default.nix
+++ b/modules/desktop/default.nix
@@ -1,4 +1,4 @@
# Desktop - Desktop environment configuration (i3/Hyprland, GTK, polybar)
{
lib,
config,
@@ -7,9 +7,9 @@
{
imports = [
./gtk
- ./polybar
./xdg
./hyprland
+ ./waybar
];
options.desktop = {
@@ -1,4 +1,4 @@
-# Desktop - Desktop environment configuration (i3/Hyprland, GTK, polybar)
+# Desktop - Desktop environment configuration (Hyprland, GTK, waybar)
{
lib,